# `art_modern_utils`: Python Utilities for `art_modern`

**NOTE**: This package is still under development.

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Here presents `art_modern_utils`, a collection of Python utilities for `art_modern`. In detail, it contains:

- `art-profile-fastqc`: A Python script for generating FASTQC-like report for ART-compatible error profiles.
- `art-sam-validate`: A Python script for validating SAM/BAM files generated by ART.
